@@ -1,6 +1,4 @@
-from m.core import one_of, subprocess
-from m.core.fp import OneOf
-from m.core.issue import Issue
+from m.core import Good, Issue, OneOf, issue, one_of, subprocess
 
 
 def get_branch() -> OneOf[Issue, str]:
@@ -12,6 +10,45 @@ def get_branch() -> OneOf[Issue, str]:
     return subprocess.eval_cmd('git rev-parse --abbrev-ref HEAD')
 
 
+def stage_all() -> OneOf[Issue, str]:
+    """Stage the current changes in the branch.
+
+    Returns:
+        A `OneOf` containing an `Issue` or the response from `git add .`.
+    """
+    return subprocess.eval_cmd('git add .').flat_map_bad(
+        lambda err: issue('git add failure', cause=err),
+    )
+
+
+def commit(msg: str) -> OneOf[Issue, str]:
+    """Create a commit.
+
+    Args:
+        msg: commit description.
+
+    Returns:
+        A `OneOf` containing an `Issue` or the response from the git command.
+    """
+    return subprocess.eval_cmd(f'git commit -m "{msg}"').flat_map_bad(
+        lambda err: issue('git commit failure', cause=err),
+    )
+
+
+def push_branch(branch: str) -> OneOf[Issue, str]:
+    """Push branch.
+
+    Args:
+        branch: name of branch to push.
+
+    Returns:
+        A `OneOf` containing an `Issue` or the response from the command.
+    """
+    return subprocess.eval_cmd(f'git push -u origin "{branch}"').flat_map_bad(
+        lambda err: issue('git push failure', cause=err),
+    )
+
+
 def stash() -> OneOf[Issue, str]:
     """Stash the current changes in the branch.
 
@@ -30,16 +67,20 @@ def stash_pop() -> OneOf[Issue, str]:
     return subprocess.eval_cmd('git stash pop')
 
 
-def checkout_branch(branch: str) -> OneOf[Issue, str]:
+def checkout_branch(branch: str, create: bool = True) -> OneOf[Issue, str]:
     """Checkout a branch.
 
     Args:
         branch: name of branch to checkout
+        create: create new branch
 
     Returns:
         A `OneOf` containing an `Issue` of the git response.
     """
-    return subprocess.eval_cmd(f'git checkout -b {branch}')
+    opt = '-b' if create else ''
+    return subprocess.eval_cmd(f'git checkout {opt} {branch}').flat_map_bad(
+        lambda err: issue('git checkout failure', cause=err),
+    )
 
 
 def get_first_commit_sha() -> OneOf[Issue, str]:
@@ -69,9 +110,14 @@ def get_remote_url() -> OneOf[Issue, str]:
     return subprocess.eval_cmd('git config --get remote.origin.url')
 
 
-def get_commits(first: str, latest: str = 'HEAD') -> OneOf[Issue, list[str]]:
+def get_commits(
+    first: str,
+    latest: str = 'HEAD',
+) -> OneOf[Issue, list[str] | None]:
     """Get a list of all the commits between two tags.
 
+    May return `None` in the special case when `first` is `0.0.0`.
+
     Args:
         first: The first tag.
         latest: The second tag, defaults to HEAD.
@@ -79,6 +125,8 @@ def get_commits(first: str, latest: str = 'HEAD') -> OneOf[Issue, list[str]]:
     Returns:
         A `OneOf` containing an `Issue` or a list of all the commits.
     """
+    if first == '0.0.0':
+        return Good(None)
     cmd = f'git log {latest}...{first} --oneline --no-color'
     return subprocess.eval_cmd(cmd).map(lambda out: out.splitlines())
 
@@ -114,3 +162,12 @@ def get_status() -> OneOf[Issue, tuple[str, str]]:
             for msg in res
         ],
     )
+
+
+def raw_status() -> OneOf[Issue, str]:
+    """Obtain the output of "git status".
+
+    Returns:
+        A `OneOf` containing an `Issue` or the output of "git status".
+    """
+    return subprocess.eval_cmd('git status')
